.. _ref_getting_started:

Getting started
===============

This section describes how to install Ansys Common Tools in user mode.
If you are interested in contributing to Ansys Common Tools, see
:ref:`contribute` for information on installing in developer mode.

Installation
------------

To use `pip <https://pypi.org/project/pip/>`_ to install Ansys Common Tools,
run this command:

.. code:: bash

        pip install ansys-tools-common

Alternatively, to install the latest version from this library's
`GitHub repository <https://github.com/ansys/ansys-tools-common/>`_,
run these commands:

.. code:: bash

    git clone https://github.com/ansys/ansys-tools-common
    cd ansys-tools-common
    pip install .